#
# Conditional build:
%bcond_without	xen		# Xen support
%bcond_with	booke		# [PPC] build for BookE
%bcond_with	gamecube	# [PPC] build for GameCube

%ifarch x32
# Xen not (yet?) available
%undefine	with_xen
%endif
Summary:	Tool for starting new kernel without reboot
Summary(pl.UTF-8):	Narzędzie pozwalające załadować nowe jądro bez konieczności restartu
Name:		kexec-tools
Version:	2.0.13
Release:	1
License:	GPL v2
Group:		Applications/System
Source0:	https://www.kernel.org/pub/linux/utils/kernel/kexec/%{name}-%{version}.tar.xz
# Source0-md5:	a28b7fd28f75861508850710f1435de5
Source1:	kexec.init
Source2:	kexec.sysconfig
Patch0:		%{name}-format.patch
Patch1:		%{name}-xen.patch
# from http://patchwork.openembedded.org/patch/90971/raw/
Patch2:		%{name}-x32.patch
URL:		https://www.kernel.org/pub/linux/utils/kernel/kexec/
BuildRequires:	autoconf >= 2.50
BuildRequires:	rpmbuild(macros) >= 1.228
BuildRequires:	tar >= 1:1.22
%{?with_xen:BuildRequires:	xen-devel >= 4.4}
BuildRequires:	xz
BuildRequires:	xz-devel
BuildRequires:	zlib-devel
Requires(post,preun):	/sbin/chkconfig
Requires:	rc-scripts >= 0.4.0.9
ExclusiveArch:	%{ix86} %{x8664} x32 alpha arm cris ia64 m68k mips ppc ppc64 s390 s390x sh
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define		_sbindir	/sbin

%description
kexec is a set of system calls that allows you to load another kernel
from the currently executing Linux kernel. The current implementation
has only been tested, and had the kinks worked out on x86, but the
generic code should work on any architecture.

%description -l pl.UTF-8
kexec to zestaw wywołań systemowych pozwalających załadować następne
jądro z poziomu aktualnie działającego jądra Linuksa. Aktualna
implementacja była testowana tylko na x86, ale ogólny kod powinien
działać na każdej architekturze.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
%{__autoconf}
%configure \
	%{?with_booke:--with-booke} \
	%{?with_gamecube:--with-gamecube} \
	%{!?with_xen:--without-xen}
%{__make}

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT/etc/{sysconfig,rc.d/init.d}

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

install %{SOURCE1} $RPM_BUILD_ROOT/etc/rc.d/init.d/kexec
cp -a %{SOURCE2} $RPM_BUILD_ROOT/etc/sysconfig/kexec

%clean
rm -rf $RPM_BUILD_ROOT

%post
/sbin/chkconfig --add kexec
%service kexec restart

%preun
if [ "$1" = "0" ]; then
	%service -q kexec stop
	/sbin/chkconfig --del kexec
fi

%files
%defattr(644,root,root,755)
%doc AUTHORS News TODO
%attr(754,root,root) /etc/rc.d/init.d/kexec
%config(noreplace) %verify(not md5 mtime size) /etc/sysconfig/kexec
%attr(755,root,root) %{_sbindir}/kdump
%attr(755,root,root) %{_sbindir}/kexec
%attr(755,root,root) %{_sbindir}/vmcore-dmesg
%{_mandir}/man8/kdump.8*
%{_mandir}/man8/kexec.8*
%{_mandir}/man8/vmcore-dmesg.8*
%ifarch %{ix86} x32
%dir %{_libdir}/kexec-tools
# what is this anyway, is it needed on other arches?
%attr(755,root,root) %{_libdir}/kexec-tools/kexec_test
%endif
%changelog
* Fri Oct 07 2016 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/kexec-tools.git;a=log;h=master

* Thu Oct 06 2016 Jakub Bogusz <qboosh@pld-linux.org> b5b0d62
- updated to 2.0.13

* Sat Apr 16 2016 Jan Rękorajski <baggins@pld-linux.org> ed3f711
- release 3 (by relup.sh)

* Thu Mar 31 2016 Jakub Bogusz <qboosh@pld-linux.org> ce7373c
- added x32 patch, build also on x32 (without xen for now); release 2

* Wed Mar 30 2016 Jakub Bogusz <qboosh@pld-linux.org> 749d2a4
- updated to 2.0.12

* Mon Jan 18 2016 Jakub Bogusz <qboosh@pld-linux.org> d689af8
- updated to 2.0.11
- added xen patch (fixes build with xen (4.6) headers)

* Wed Jul 01 2015 Jakub Bogusz <qboosh@pld-linux.org> d00ae1a
- updated to 2.0.10

* Mon Feb 23 2015 Jakub Bogusz <qboosh@pld-linux.org> 8b90915
- updated to 2.0.9

* Mon Oct 13 2014 Jakub Bogusz <qboosh@pld-linux.org> 423cbcd
- updated to 2.0.8
- xen support seems to require Xen 4.4

* Thu Jun 12 2014 Jakub Bogusz <qboosh@pld-linux.org> 5de6f64
- updated to 2.0.7

* Fri Mar 07 2014 Jakub Bogusz <qboosh@pld-linux.org> 47aeab0
- updated to 2.0.6
- removed obsolete efi patch

* Sat Feb 08 2014 Jakub Bogusz <qboosh@pld-linux.org> e2ad210
- updated format patch to cover x86_64 specific files too

* Sat Feb 08 2014 Jakub Bogusz <qboosh@pld-linux.org> da5ba34
- updated to 2.0.5
- added format patch (fixes build with -Werror=format-security)
- added efi patch (fixes x86 build after adding EFI support for x86_64)

* Sun Nov 03 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> c82dd91
- release 3 (by relup.sh)

* Fri May 31 2013 Elan Ruusamäe <glen@delfi.ee> 14b4ad9
- release 2 (by relup.sh)

* Thu May 30 2013 Elan Ruusamäe <glen@delfi.ee> efc519b
- fix default INITRD path in config

* Fri Mar 22 2013 Jakub Bogusz <qboosh@pld-linux.org> 7bed061
- updated to 2.0.4
- handle xen bcond
- added bconds for booke/gamecube (PPC-specific)

* Sat Feb 16 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> c819c1a
- no kexec_test on x86_64

* Thu Jan 19 2012 Jakub Bogusz <qboosh@pld-linux.org> c894912
- updated to 2.0.3

* Thu Jun 02 2011 Elan Ruusamäe <glen@pld-linux.org> e6595bd
- release 4

* Thu Jun 02 2011 Elan Ruusamäe <glen@pld-linux.org> ccadf75
- print kernel and initrd info in status action

